# StarBot_Utils - Shared tools

The "StarBot_Utils" sub-folder is a PIP package for use with StarBot.

## Version Information

Versions are in the format of:
Release.Beta.Alpha

When these Utils are ready for good use, then it will be 1.0.0.

I will have StarBot on PyPi for public use, I just won't be providing documentation on how to start it. Contact me on discord: xgg69420x